import { Vue } from 'vue-property-decorator';
import { ButtonTypes } from './consts';
export default class MyButton extends Vue {
    readonly ButtonTypes: typeof ButtonTypes;
    /**
     * Type of button. Possible values: "primary", "secondary", "tertiary", "delete".
     * By default it's set to "primary"
     */
    readonly type: string;
    /**
     * Size of button. Possible values: "big", "medium", "small".
     * By default it's set to "big"
     */
    readonly size: string;
    /**
     * Icon name from icon collection of this library
     */
    readonly icon: string;
    /**
     * Disable state
     */
    readonly disabled: boolean;
    /**
     * Loading state. Only "tertiary" button cannot have this state
     *
     * If you use `loading` state for one button, for instance, [Send][Cancel], and "send" button sent
     * request to back-end side, you should use `loading` state ONLY for "send" button and apply this flag
     * to "cancel" button `disabled` state. So, if "send" has `loading` state, "cancel" should be `disabled`
     */
    readonly loading: boolean;
    /**
     * Autofocus property, same as native button's `autofocus`
     */
    readonly autofocus: boolean;
    /**
     * Tooltip
     */
    readonly tooltip: string;
    /**
     * Button's native type. Possible values: "button", "submit", "reset".
     * By default it's set to "button"
     */
    readonly nativeType: string;
    elementIcon: string;
    get computedSize(): string;
    get computedType(): string;
    get computedClasses(): Array<string>;
    get availableIcon(): string;
    get isLoading(): boolean;
    handleClick(): void;
}
